# Generated by Django 2.2 on 2019-07-09 18:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('anss', '0005_auto_20190709_1035'),
    ]

    operations = [
        migrations.AlterField(
            model_name='feedearthquake',
            name='status',
            field=models.CharField(blank=True, help_text='Indicates whether the event has been reviewed by a human. Status is either automatic or reviewed. Automatic events are directly posted by automatic processing systems and have not been verified or altered by a human. Reviewed events have been looked at by a human. The level of review can range from a quick validity check to a careful reanalysis of the event.', max_length=5000),
        ),
        migrations.AlterField(
            model_name='feedearthquake',
            name='title',
            field=models.CharField(blank=True, help_text='A summary of the event', max_length=5000, verbose_name='description'),
        ),
    ]
